==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-split-panel/xl-react-widget-collapsible-vertical-split-pane/xl-react-widget-collapsible-vertical-split-pane-component.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import SplitPane from 'react-split-pane';
import classnames from 'classnames';
import RU from '../../../utils/ramda-utils';

import './xl-react-widget-collapsible-vertical-split-pane.less';

import {FULL_PANE_WIDTH, HIDE_PANE_WIDTH, SIDES} from './xl-react-widget-collapsible-vertical-split-pane-constants';

export class XlReactWidgetCollapsibleVerticalSplitPanel extends Component {
    static propTypes = {
        children: PropTypes.oneOfType([PropTypes.object, PropTypes.array]).isRequired,
        className: PropTypes.string,
        isCollapsed: PropTypes.bool,
        minPrimarySideWidth: PropTypes.number.isRequired,
        minSecondarySideWidth: PropTypes.number.isRequired,
        onChangeWidth: PropTypes.func,
        primary: PropTypes.oneOf([SIDES.primary, SIDES.secondary]),
        primarySideWidth: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
        shouldAnimate: PropTypes.bool,
        sideToCollapse: PropTypes.oneOf([SIDES.primary, SIDES.secondary]).isRequired
    };

    static defaultProps = {
        primary: SIDES.primary,
        shouldAnimate: true
    };

    constructor(props) {
        super(props);
        const {primarySideWidth, isCollapsed} = this.props;
        this.state = {
            primarySideWidth: this.getCalculatedWidth(isCollapsed, primarySideWidth),
            shouldAnimate: this.props.shouldAnimate
        };
    }

    componentWillReceiveProps(nextProps) {
        this.handleCollapseToggle(nextProps);
    }

    handleCollapseToggle(nextProps) {
        const {isCollapsed = false, primarySideWidth} = nextProps;
        if (isCollapsed) {
            this.collapseSelectedSide(isCollapsed, primarySideWidth);
        } else {
            this.setBackToRememberedWidth(nextProps.primarySideWidth);
        }
    }

    handleDragEnd = () => {
        if (this.state.shouldAnimate !== true) {
            this.setState({shouldAnimate: true});
        }
    };

    handleDragStart = () => {
        if (this.state.shouldAnimate !== false) {
            this.setState({shouldAnimate: false});
        }
    };

    handlePaneWidthChange = (size) => {
        this.setState({primarySideWidth: size});
        RU.invoke(['onChangeWidth'], [size], this.props);
    };

    collapseSelectedSide(isCollapsed, primarySideWidth) {
        this.setState({primarySideWidth: this.getCalculatedWidth(true, primarySideWidth)});
    }

    setBackToRememberedWidth(primarySideWidth) {
        this.setState({primarySideWidth});
    }

    getCalculatedWidth(isCollapsed, defaultWidth) {
        return R.cond([
            [this.isPrimaryAndPrimaryIsCollapsed, () => HIDE_PANE_WIDTH],
            [this.isPrimaryAndSecondaryIsCollapsed, () => FULL_PANE_WIDTH],
            [this.isSecondaryAndPrimaryIsCollapsed, () => FULL_PANE_WIDTH],
            [this.isSecondaryAndSecondaryIsCollapsed, () => HIDE_PANE_WIDTH],
            [R.T, () => defaultWidth]
        ])(isCollapsed);
    }

    isPrimaryAndPrimaryIsCollapsed = (isCollapsed) =>
        isCollapsed &&
        this.props.primary === SIDES.primary &&
        this.props.sideToCollapse === SIDES.primary;

    isPrimaryAndSecondaryIsCollapsed = (isCollapsed) =>
        isCollapsed &&
        this.props.primary === SIDES.primary &&
        this.props.sideToCollapse === SIDES.secondary;

    isSecondaryAndPrimaryIsCollapsed = (isCollapsed) =>
        isCollapsed &&
        this.props.primary === SIDES.secondary &&
        this.props.sideToCollapse === SIDES.primary;

    isSecondaryAndSecondaryIsCollapsed = (isCollapsed) =>
        isCollapsed &&
        this.props.primary === SIDES.secondary &&
        this.props.sideToCollapse === SIDES.secondary;

    render() {
        const {primarySideWidth, shouldAnimate} = this.state;
        const {
            className,
            children,
            minSecondarySideWidth,
            minPrimarySideWidth,
            primary
        } = this.props;
        const animationClass = classnames(className, 'xl-react-widget-collapsible-vertical-split-pane',
            {'close-animation': shouldAnimate}
        );
        return <div className={animationClass}>
            <SplitPane
                maxSize={-minSecondarySideWidth}
                minSize={minPrimarySideWidth}
                onChange={this.handlePaneWidthChange}
                onDragFinished={this.handleDragEnd}
                onDragStarted={this.handleDragStart}
                primary={primary}
                resizerStyle={{
                    minWidth: 8,
                    width: 8
                }}
                size={primarySideWidth}
                split="vertical">
                {children[0]}
                {children[1]}
            </SplitPane>
        </div>;
    }
}

==> xl-react-components-0.21.16.tgz: package/app/xl-react-widget/xl-react-widget-split-panel/xl-react-widget-collapsible-vertical-split-pane/xl-react-widget-collapsible-vertical-split-pane-component.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import SplitPane from 'react-split-pane';
import classnames from 'classnames';
import RU from '../../../utils/ramda-utils';

import './xl-react-widget-collapsible-vertical-split-pane.less';

import {FULL_PANE_WIDTH, HIDE_PANE_WIDTH, SIDES} from './xl-react-widget-collapsible-vertical-split-pane-constants';

export class XlReactWidgetCollapsibleVerticalSplitPanel extends Component {
    static propTypes = {
        allowResize: PropTypes.bool,
        children: PropTypes.oneOfType([PropTypes.object, PropTypes.array]).isRequired,
        className: PropTypes.string,
        isCollapsed: PropTypes.bool,
        minPrimarySideWidth: PropTypes.number.isRequired,
        minSecondarySideWidth: PropTypes.number.isRequired,
        onChangeWidth: PropTypes.func,
        primary: PropTypes.oneOf([SIDES.primary, SIDES.secondary]),
        primarySideWidth: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
        resizerStyle: PropTypes.object,
        shouldAnimate: PropTypes.bool,
        sideToCollapse: PropTypes.oneOf([SIDES.primary, SIDES.secondary]).isRequired
    };

    static defaultProps = {
        allowResize: true,
        primary: SIDES.primary,
        resizerStyle: {
            minWidth: 8,
            width: 8
        },
        shouldAnimate: true
    };

    constructor(props) {
        super(props);
        const {primarySideWidth, isCollapsed} = this.props;
        this.state = {
            primarySideWidth: this.getCalculatedWidth(isCollapsed, primarySideWidth),
            shouldAnimate: this.props.shouldAnimate
        };
    }

    UNSAFE_componentWillReceiveProps(nextProps) {
        this.handleCollapseToggle(nextProps);
    }

    handleCollapseToggle(nextProps) {
        const {isCollapsed = false, primarySideWidth} = nextProps;
        if (isCollapsed) {
            this.collapseSelectedSide(isCollapsed, primarySideWidth);
        } else {
            this.setBackToRememberedWidth(nextProps.primarySideWidth);
        }
    }

    handleDragEnd = () => {
        if (this.state.shouldAnimate !== true) {
            this.setState({shouldAnimate: true});
        }
    };

    handleDragStart = () => {
        if (this.state.shouldAnimate !== false) {
            this.setState({shouldAnimate: false});
        }
    };

    handlePaneWidthChange = (size) => {
        this.setState({primarySideWidth: size});
        RU.invoke(['onChangeWidth'], [size], this.props);
    };

    collapseSelectedSide(isCollapsed, primarySideWidth) {
        this.setState({primarySideWidth: this.getCalculatedWidth(true, primarySideWidth)});
    }

    setBackToRememberedWidth(primarySideWidth) {
        this.setState({primarySideWidth});
    }

    getCalculatedWidth(isCollapsed, defaultWidth) {
        return R.cond([
            [this.isPrimaryAndPrimaryIsCollapsed, () => HIDE_PANE_WIDTH],
            [this.isPrimaryAndSecondaryIsCollapsed, () => FULL_PANE_WIDTH],
            [this.isSecondaryAndPrimaryIsCollapsed, () => FULL_PANE_WIDTH],
            [this.isSecondaryAndSecondaryIsCollapsed, () => HIDE_PANE_WIDTH],
            [R.T, () => defaultWidth]
        ])(isCollapsed);
    }

    isPrimaryAndPrimaryIsCollapsed = (isCollapsed) =>
        isCollapsed &&
        this.props.primary === SIDES.primary &&
        this.props.sideToCollapse === SIDES.primary;

    isPrimaryAndSecondaryIsCollapsed = (isCollapsed) =>
        isCollapsed &&
        this.props.primary === SIDES.primary &&
        this.props.sideToCollapse === SIDES.secondary;

    isSecondaryAndPrimaryIsCollapsed = (isCollapsed) =>
        isCollapsed &&
        this.props.primary === SIDES.secondary &&
        this.props.sideToCollapse === SIDES.primary;

    isSecondaryAndSecondaryIsCollapsed = (isCollapsed) =>
        isCollapsed &&
        this.props.primary === SIDES.secondary &&
        this.props.sideToCollapse === SIDES.secondary;

    render() {
        const {primarySideWidth, shouldAnimate} = this.state;
        const {
            allowResize,
            className,
            children,
            minSecondarySideWidth,
            minPrimarySideWidth,
            primary,
            resizerStyle
        } = this.props;
        const animationClass = classnames(className, 'xl-react-widget-collapsible-vertical-split-pane',
            {'close-animation': shouldAnimate}
        );
        return <div className={animationClass}>
            <SplitPane
                allowResize={allowResize}
                maxSize={-minSecondarySideWidth}
                minSize={minPrimarySideWidth}
                onChange={this.handlePaneWidthChange}
                onDragFinished={this.handleDragEnd}
                onDragStarted={this.handleDragStart}
                primary={primary}
                resizerClassName="xl-icon options-icon"
                resizerStyle={resizerStyle}
                size={primarySideWidth}
                split="vertical">
                {children[0]}
                {children[1]}
            </SplitPane>
        </div>;
    }
}
